
import java.io.*;
import java.util.*;

public class CipherSolver
{
    // Adds a space between all the letters in a string.
    // This needs to be called before sending text to the language model for scoring.
    public static String addSpaces(String str)
    {
        StringBuffer result = new StringBuffer();
        for (int i = 0; i < str.length(); i++)
        {
            if (i > 0)
                result.append(" ");
            result.append(str.charAt(i));
        }
        return result.toString();
    }
    
    public static void main(String [] args)
    {
        if (args.length < 4)
        {
            System.out.println("CipherSolver <cipher file> <LM file> <time limit> <output file> ...");
            return;
        }
        
        String cipherFile   = args[0];
        String lmFile       = args[1];
        double timeLimit    = Double.parseDouble(args[2]);        
        String outFile      = args[3];
        
        Stats stats = new Stats();
        try
        {
            // First read all the cipher text into one big String with whitespace removed
            StringBuffer cipherText = new StringBuffer();
            Scanner scanner = new Scanner(new File(cipherFile));      
            while (scanner.hasNext())
                cipherText.append(scanner.nextLine().replaceAll("\\s", ""));
            scanner.close();
            String cipher = cipherText.toString();

            System.out.println("LM          : " + lmFile);
            NGramLM lm = new NGramLM(lmFile);
            System.out.println("time limit  : " + timeLimit);
            System.out.println("Cipher text :\n" + cipherText);     
 
            float bestLogProb = Float.NEGATIVE_INFINITY;
            
            // Keep searching until time limit is exceeded
            while (stats.elapsedTime() < timeLimit)
            {
                // This shows how to score a sentence using the language model class.
                bestLogProb= lm.GetSentLogProb(addSpaces("thecurrentplaintextdecryptiongoeshere"));                              
            }

            System.out.println(bestLogProb);
            
        }
        catch (IOException e)
        {
            e.printStackTrace();
        }
    }
    

}
