/*
 * Ported from: NGramLMTypes.h (Original Author: Keith Vertanen)
 */

import java.io.PrintStream;
import java.util.Iterator;
import java.util.List;

public class NGram4 extends NGramLMBase {

	public int[]					m_pWords = new int[4];

	public NGram4(float fLogProb, float fLogBackoff, int iID1, int iID2, int iID3, int iID4)
	{ 
		m_fLogProb		= fLogProb;
		m_fLogBackoff	= fLogBackoff;
		m_pWords[0]		= iID1; 
		m_pWords[1]		= iID2; 
		m_pWords[2]		= iID3; 
		m_pWords[3]		= iID4; 
	}

	public NGram4(float fLogProb, float fLogBackoff, List<Integer> vecIDs)
	{ 
		m_fLogProb		= fLogProb;
		m_fLogBackoff	= fLogBackoff;
		int i = 0;
		Iterator<Integer> iter = vecIDs.iterator();
		while (iter.hasNext()) {
			if (vecIDs.size() == 4)
				m_pWords[i] = iter.next().intValue();
			else
				m_pWords[i]	= NGramLMTypes.NGRAM_WORD_ID_MAX;
			++i;
		}
	}

	public String GetWords(List<String> pWords)
	{
		String strResult = "";
		if (pWords != null)
		{
			for (int i = 0; i < 4; ++i)
			{
				if (i > 0)
					strResult += " ";
				strResult += pWords.get(m_pWords[i]);
			}
		}
		return strResult;
	}

	public void Write(PrintStream fp, int iTrunc, boolean bWriteBackoff, List<String> pWords)
	{
		if (fp != null)
		{
			WriteTruncFloat(fp, m_fLogProb / NGramLMTypes.LN_10, iTrunc);						
			fp.printf("\t%s %s %s %s", pWords.get(m_pWords[0]), pWords.get(m_pWords[1]), pWords.get(m_pWords[2]), pWords.get(m_pWords[3]));
			if (bWriteBackoff)
			{
				fp.printf("\t");
				WriteTruncFloat(fp, m_fLogBackoff / NGramLMTypes.LN_10, iTrunc);
			}
			fp.printf("\n");
		}
	}
	
	public int	GetSize()			
	{ 
		return 4; 
	}
	
	public int	GetFirstID()
	{
		return m_pWords[0];
	}
	
	public int	GetLastID()
	{
		return m_pWords[3];
	}
	
	public int	GetID(int iPos)
	{
		if (iPos < 4)
			return m_pWords[iPos];
		return NGramLMTypes.NGRAM_WORD_ID_MAX;
	}
	
}
