/*
 * Ported from: NGramLMTypes.h (Original Author: Keith Vertanen)
 */

import java.io.PrintStream;
import java.util.List;

/**
 * We have a hierarchy of classes to represent n-grams during loading of the ARPA LM.  
 * There are subclasses for the most common lower order n-grams since ths saves memory.
 */
public abstract class NGramLMBase {

	public abstract int					GetSize();			
	public abstract int					GetFirstID();
	public abstract int					GetLastID();
	public abstract int					GetID(int iPos);
	public abstract void				Write(PrintStream fp, int iTrunc, boolean bWriteBackoff, List<String> pWords);
	public abstract String				GetWords(List<String> pWords);
	public float						m_fLogProb;			// log prob of this gram, log base e
	public float						m_fLogBackoff;		// log backoff weight for this gram, log base e
	
	// Write a truncated decimal to an open file handle.
	public static void WriteTruncFloat(PrintStream fp, float fValue, int iTrunc)
	{
		if (fp == null)
			return;
		if (iTrunc == 0)
			fp.printf("%f", fValue);			
		else
			fp.printf("%.*f", iTrunc, fValue);			
	}
	
	public static void WriteTruncFloat(PrintStream fp, double fValue, int iTrunc)
	{
		if (fp == null)
			return;
		if (iTrunc == 0)
			fp.printf("%f", fValue);			
		else
			fp.printf("%.*f", iTrunc, fValue);			
	}
	
}
