import java.io.*;
import java.util.*;

public class Score
{ 
    private static int minimum(int a, int b, int c) 
    {
        return Math.min(Math.min(a, b), c);
    }

    // Taken from: http://en.wikibooks.org/wiki/Algorithm_Implementation/Strings/Levenshtein_distance#Java
    public static int computeLevenshteinDistance(String str1, String str2) 
    {
        int[][] distance = new int[str1.length() + 1][str2.length() + 1];

        for (int i = 0; i <= str1.length(); i++)
            distance[i][0] = i;
        for (int j = 1; j <= str2.length(); j++)
            distance[0][j] = j;

        for (int i = 1; i <= str1.length(); i++)
            for (int j = 1; j <= str2.length(); j++)
                distance[i][j] = minimum(
                        distance[i - 1][j] + 1,
                        distance[i][j - 1] + 1,
                        distance[i - 1][j - 1]
                                + ((str1.charAt(i - 1) == str2.charAt(j - 1)) ? 0
                                        : 1));

        return distance[str1.length()][str2.length()];
    }

    public static double computeCER(String rec, String ref)
    {
        int dist = computeLevenshteinDistance(rec, ref);
        return (double) dist / ref.length() * 100.0;
    }

    public static void main(String [] args)
    {
        try
        {
	    int limit = 0;
	    if (args.length > 2)
		limit = Integer.parseInt(args[2]);

            Scanner scanRec = new Scanner(new File(args[0]));
            String rec = "";
            while (scanRec.hasNext())
                rec = scanRec.nextLine().toLowerCase().replaceAll("[^a-z]", "");

            scanRec.close();

	    if (limit > 0)
		rec = rec.substring(0, limit);
            System.out.println("REC: " + rec);

            Scanner scanRef = new Scanner(new File(args[1]));
            String ref = "";
            while (scanRef.hasNext())
                ref +=scanRef.next().toLowerCase().replaceAll("[^a-z]", "");

            scanRef.close();

	    if (limit > 0)
		ref = ref.substring(0, limit);
            System.out.println("REF: " + ref);

            System.out.printf("CER: %.3f\n", computeCER(rec, ref));
        }
        catch (FileNotFoundException e)
        {
            e.printStackTrace();
        }
    }
}